<template>
	<view >
		<uni-forms label-width="120" class="customcss">
			<uni-forms-item label="货位编号">
				<uni-easyinput type="text" v-model="locationNo" :focus="!barcodefocus" placeholder="请输入货位编号"
					@input="locationNoinputChange()" ref='midInput'/>
			</uni-forms-item>
			<uni-forms-item>
				<button @click="submit" type="primary" size="default" style="margin-top: 2%;">解除绑定</button>
			</uni-forms-item>
		</uni-forms>
		<uni-list class="footer">
			<uni-list-item direction="column" v-for="item in stockInfo" :key="item.matCode">
				<template v-slot:body>
					<view class="uni-list-box">
						<view class="uni-content">
							<view class="uni-title-sub uni-ellipsis-2">容器编号：{{item.palletCode}}</view>
							<view class="uni-title-sub uni-ellipsis-2">物料编码：{{item.matCode}}</view>
							<view class="uni-title-sub uni-ellipsis-2">物料名称：{{item.mater_name}}</view>
							<view class="uni-title-sub uni-ellipsis-2">数量：{{item.quantity}}</view>
							<view class="uni-title-sub uni-ellipsis-2">货位编号：{{item.locationCode}}</view>
						</view>
					</view>
				</template>
			</uni-list-item>
		</uni-list>
		<u-toast ref="uToast" />
	</view>
</template>

<script>
	export default {
		data() {
			return {
				locationNo: "",
				barcode: '',
				barcodefocus: false,
				stockInfo: []
			}
		},
		onLoad(res) {
		},
		methods: {
			submit() {
				if (this.locationNo == "") {
					this.$refs.uToast.show({
						title: "货位号不能为空",
						type: "error"
					});
					return;
				}
				var _this = this;
				var isDelete = false;
				uni.showModal({
					title: "提示",
					cancelText:'否',
					confirmText:'是',
					confirmColor:'blue',
					content: "是否删除库存?",
					showCancel: true,
					success: function(res) {
						if (res.confirm) {
							isDelete = true;
						} else if (res.cancel) {
							isDelete = false;
						}
						_this.releaseStock(isDelete);
					}
				});

			},
			releaseStock(isDelete) {
				var postData = {
					MainData: {
						"locationNo": this.locationNo,
						"barcode": this.barcode
					},
					Extra: isDelete
				}
				this.$u.post('/api/StockOperate/ReleaseStock', postData).then((res) => {
					if (res.status) {
						this.items = [];
						this.stockInfo = [];
						this.$refs.uToast.show({
							title: res.message,
							type: "success"
						});
						this.locationNo = "";
						this.barcode = "";
						this.barcodefocus = false;
					} else {
						this.$refs.uToast.show({
							title: res.message,
							type: "error"
						});
					}
				})
			},
			updateFocus() {

			},
			locationNoinputChange() {
				this.$nextTick(function(x) {
					if (this.locationNo != '') {
						var postData = {
							MainData: {
								"locationCode": this.locationNo
							},
						}
						this.$u.post('/api/VV_StockGroup/GetStockInfoByLocationNo', postData).then((res) => {
							if (res.status) {
								this.stockInfo = res.data;
							} else {
								this.$refs.uToast.show({
									title: res.message,
									type: "error"
								});
							}
						})
					}
				})
			}
		}
	}
</script>

<style lang="scss">
	@import '@/common/uni-ui.scss';

	page {
		display: flex;
		flex-direction: column;
		box-sizing: border-box;
		background-color: #efeff4;
		min-height: 100%;
		height: auto;
	}

	.tips {
		color: #67c23a;
		font-size: 14px;
		line-height: 40px;
		text-align: center;
		background-color: #f0f9eb;
		height: 0;
		opacity: 0;
		transform: translateY(-100%);
		transition: all 0.3s;
	}

	.tips-ani {
		transform: translateY(0);
		height: 40px;
		opacity: 1;
	}

	.content {
		width: 100%;
		display: flex;
	}

	.list-picture {
		width: 100%;
		height: 145px;
	}

	.thumb-image {
		width: 100%;
		height: 100%;
	}

	.ellipsis {
		display: flex;
		overflow: hidden;
	}

	.uni-ellipsis-1 {
		overflow: hidden;
		white-space: nowrap;
		text-overflow: ellipsis;
	}

	.uni-ellipsis-2 {
		overflow: hidden;
		text-overflow: ellipsis;
		display: -webkit-box;
		-webkit-line-clamp: 2;
		-webkit-box-orient: vertical;
	}

	.customcss {
		background-color: #fff;
		padding: 20rpx 40rpx;
		width: 100%;
	}

	.footer {
		// padding-top: 20%;
	}
</style>
